@@ -35,7 +35,7 @@ from pyramid.renderers import render
 from pyramid_simpleform import Form
 from pyramid_simpleform.renderers import FormRenderer
 
-from edbob.core import Object
+from rattail.core import Object
 from edbob.util import prettify
 
 
