@@ -73,7 +73,7 @@ def context_found(event):
         return has_permission(Session(), request.user, perm)
     request.has_perm = has_perm
 
-    def has_any_perm(perms):
+    def has_any_perm(*perms):
         for perm in perms:
             if has_permission(Session(), request.user, perm):
                 return True
