@@ -31,6 +31,7 @@ from pyramid.renderers import render_to_response
 
 from webhelpers.html import tags
 
+import edbob
 from edbob.pyramid.forms import PrettyDateTimeFieldRenderer
 from ...forms import EnumFieldRenderer
 from ...grids.search import BooleanSearchFilter
@@ -140,7 +141,8 @@ class BatchCrud(CrudView):
 class ExecuteBatch(View):
 
     def execute_batch(self, batch, progress):
-        from rattail.db import Session
+        from rattail.db import get_session_class
+        Session = get_session_class(edbob.config)
         session = Session()
         batch = session.merge(batch)
 
