@@ -28,43 +28,39 @@ Customer Views
 
 from sqlalchemy import and_
 
-from edbob.enum import EMAIL_PREFERENCE
-
-from . import SearchableAlchemyGridView
+from . import SearchableAlchemyGridView, CrudView
 from ..forms import EnumFieldRenderer
 
-import rattail
 from ..db import Session
-from rattail.db.model import (
-    Customer, CustomerPerson, CustomerGroupAssignment,
-    CustomerEmailAddress, CustomerPhoneNumber)
-from . import CrudView
+
+from rattail import enum
+from rattail.db import model
 
 
 class CustomersGrid(SearchableAlchemyGridView):
 
-    mapped_class = Customer
+    mapped_class = model.Customer
     config_prefix = 'customers'
     sort = 'name'
 
     def join_map(self):
         return {
             'email':
-                lambda q: q.outerjoin(CustomerEmailAddress, and_(
-                    CustomerEmailAddress.parent_uuid == Customer.uuid,
-                    CustomerEmailAddress.preference == 1)),
+                lambda q: q.outerjoin(model.CustomerEmailAddress, and_(
+                    model.CustomerEmailAddress.parent_uuid == model.Customer.uuid,
+                    model.CustomerEmailAddress.preference == 1)),
             'phone':
-                lambda q: q.outerjoin(CustomerPhoneNumber, and_(
-                    CustomerPhoneNumber.parent_uuid == Customer.uuid,
-                    CustomerPhoneNumber.preference == 1)),
+                lambda q: q.outerjoin(model.CustomerPhoneNumber, and_(
+                    model.CustomerPhoneNumber.parent_uuid == model.Customer.uuid,
+                    model.CustomerPhoneNumber.preference == 1)),
             }
 
     def filter_map(self):
         return self.make_filter_map(
             exact=['id'],
             ilike=['name'],
-            email=self.filter_ilike(CustomerEmailAddress.address),
-            phone=self.filter_ilike(CustomerPhoneNumber.number))
+            email=self.filter_ilike(model.CustomerEmailAddress.address),
+            phone=self.filter_ilike(model.CustomerPhoneNumber.number))
 
     def filter_config(self):
         return self.make_filter_config(
@@ -77,8 +73,8 @@ class CustomersGrid(SearchableAlchemyGridView):
     def sort_map(self):
         return self.make_sort_map(
             'id', 'name',
-            email=self.sorter(CustomerEmailAddress.address),
-            phone=self.sorter(CustomerPhoneNumber.number))
+            email=self.sorter(model.CustomerEmailAddress.address),
+            phone=self.sorter(model.CustomerPhoneNumber.number))
 
     def grid(self):
         g = self.make_grid()
@@ -106,27 +102,27 @@ class CustomersGrid(SearchableAlchemyGridView):
 
 class CustomerCrud(CrudView):
 
-    mapped_class = Customer
+    mapped_class = model.Customer
     home_route = 'customers'
 
     def get_model(self, key):
         model = super(CustomerCrud, self).get_model(key)
         if model:
             return model
-        model = Session.query(Customer).filter_by(id=key).first()
+        model = Session.query(model.Customer).filter_by(id=key).first()
         if model:
             return model
-        model = Session.query(CustomerPerson).get(key)
+        model = Session.query(model.CustomerPerson).get(key)
         if model:
             return model.customer
-        model = Session.query(CustomerGroupAssignment).get(key)
+        model = Session.query(model.CustomerGroupAssignment).get(key)
         if model:
             return model.customer
         return None
 
     def fieldset(self, model):
         fs = self.make_fieldset(model)
-        fs.email_preference.set(renderer=EnumFieldRenderer(EMAIL_PREFERENCE))
+        fs.email_preference.set(renderer=EnumFieldRenderer(enum.EMAIL_PREFERENCE))
         fs.configure(
             include=[
                 fs.id.label("ID"),
