@@ -300,7 +300,8 @@ def print_labels(request):
 class CreateProductsBatch(ProductsGrid):
 
     def make_batch(self, provider, progress):
-        from rattail.db import Session
+        from rattail.db import get_session_class
+        Session = get_session_class(edbob.config)
         session = Session()
 
         self._filter_config = self.filter_config()
