@@ -32,7 +32,7 @@ from formalchemy.fields import SelectFieldRenderer
 from edbob.pyramid.views import users
 
 from . import SearchableAlchemyGridView, CrudView
-from ..forms import PersonFieldRenderer
+from ..forms import PersonFieldLinkRenderer
 from ..db import Session
 from rattail.db.model import User, Person, Role
 from rattail.db.auth import guest_role
@@ -143,8 +143,6 @@ class UserCrud(CrudView):
 
         # Must set Person options to empty set to avoid unwanted magic.
         fs.person.set(options=[])
-        fs.person.set(renderer=PersonFieldRenderer(
-                self.request.route_url('people.autocomplete')))
 
         fs.append(users.PasswordField('password'))
         fs.append(Field('confirm_password',
@@ -155,7 +153,7 @@ class UserCrud(CrudView):
         fs.configure(
             include=[
                 fs.username,
-                fs.person,
+                fs.person.with_renderer(PersonFieldLinkRenderer),
                 fs.password.label("Set Password"),
                 fs.confirm_password,
                 fs.roles,
